==> haskell-lifted-base-0.2.3.12-191-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lifted-base.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lifted-base
version:              0.2.3.12
visibility:           public
id:                   lifted-base-0.2.3.12-2c0FpFQav7yDcWLXifRSSE
key:                  lifted-base-0.2.3.12-2c0FpFQav7yDcWLXifRSSE
license:              BSD-3-Clause
copyright:            (c) 2011-2012 Bas van Dijk, Anders Kaseorg
maintainer:           Bas van Dijk <v.dijk.bas@gmail.com>
author:               Bas van Dijk, Anders Kaseorg
homepage:             https://github.com/basvandijk/lifted-base
synopsis:             lifted IO operations from the base library
description:
    @lifted-base@ exports IO operations from the base library lifted to
    any instance of '\''MonadBase'\'' or '\''MonadBaseControl'\''.

    Note that not all modules from @base@ are converted yet. If
    you need a lifted version of a function from @base@, just
    ask me to add it or send me a patch.

    The package includes a copy of the @monad-peel@ testsuite written
    by Anders Kaseorg The tests can be performed using @cabal test@.

category:             Control
abi:                  fd5c4446c2a9e1092351840a4a8062d9
exposed:              True
exposed-modules:
    Control.Concurrent.Chan.Lifted Control.Concurrent.Lifted
    Control.Concurrent.MVar.Lifted Control.Concurrent.QSem.Lifted
    Control.Concurrent.QSemN.Lifted Control.Exception.Lifted
    Data.IORef.Lifted Foreign.Marshal.Utils.Lifted
    System.Timeout.Lifted

import-dirs:          /usr/lib/ghc-9.0.2/site-local/lifted-base-0.2.3.12
library-dirs:         /usr/lib/ghc-9.0.2/site-local/lifted-base-0.2.3.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/lifted-base-0.2.3.12
hs-libraries:         HSlifted-base-0.2.3.12-2c0FpFQav7yDcWLXifRSSE
includes:             inlinable.h
depends:
    base-4.15.1.0 monad-control-1.0.3.1-85XIveeEYeUAEZsVlwkyla
    transformers-base-0.4.6-2rLwOrVFpgj3fbHl7m6Dye

haddock-interfaces:   /usr/share/doc/haskell-lifted-base/html/lifted-base.haddock
haddock-html:         /usr/share/doc/haskell-lifted-base/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lifted-base-0.2.3.12-192-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lifted-base.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lifted-base
version:              0.2.3.12
visibility:           public
id:                   lifted-base-0.2.3.12-HGbKXBbr9fjCMT7BagwNGL
key:                  lifted-base-0.2.3.12-HGbKXBbr9fjCMT7BagwNGL
license:              BSD-3-Clause
copyright:            (c) 2011-2012 Bas van Dijk, Anders Kaseorg
maintainer:           Bas van Dijk <v.dijk.bas@gmail.com>
author:               Bas van Dijk, Anders Kaseorg
homepage:             https://github.com/basvandijk/lifted-base
synopsis:             lifted IO operations from the base library
description:
    @lifted-base@ exports IO operations from the base library lifted to
    any instance of '\''MonadBase'\'' or '\''MonadBaseControl'\''.

    Note that not all modules from @base@ are converted yet. If
    you need a lifted version of a function from @base@, just
    ask me to add it or send me a patch.

    The package includes a copy of the @monad-peel@ testsuite written
    by Anders Kaseorg The tests can be performed using @cabal test@.

category:             Control
abi:                  9a772fe2cb3ee009ed6fe031fec6ed55
exposed:              True
exposed-modules:
    Control.Concurrent.Chan.Lifted Control.Concurrent.Lifted
    Control.Concurrent.MVar.Lifted Control.Concurrent.QSem.Lifted
    Control.Concurrent.QSemN.Lifted Control.Exception.Lifted
    Data.IORef.Lifted Foreign.Marshal.Utils.Lifted
    System.Timeout.Lifted

import-dirs:          /usr/lib/ghc-9.0.2/site-local/lifted-base-0.2.3.12
library-dirs:         /usr/lib/ghc-9.0.2/site-local/lifted-base-0.2.3.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/lifted-base-0.2.3.12
hs-libraries:         HSlifted-base-0.2.3.12-HGbKXBbr9fjCMT7BagwNGL
includes:             inlinable.h
depends:
    base-4.15.1.0 monad-control-1.0.3.1-sGi42tWA7N18IpNEie6cb
    transformers-base-0.4.6-8VurLrq5eojQe1DyNUAwB

haddock-interfaces:   /usr/share/doc/haskell-lifted-base/html/lifted-base.haddock
haddock-html:         /usr/share/doc/haskell-lifted-base/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
